<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    version="1.0" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:tei="http://www.tei-c.org/ns/1.0">
    
    
    <!-- Attributsets definieren -->
    <xsl:attribute-set name="title">
        <xsl:attribute name="font-size">14pt</xsl:attribute>
        <xsl:attribute name="margin-bottom">0.5cm</xsl:attribute>
    </xsl:attribute-set>
    
    <xsl:attribute-set name="standard">
        <xsl:attribute name="font-size">10pt</xsl:attribute>
        <xsl:attribute name="text-align">justify</xsl:attribute>
        <xsl:attribute name="margin-bottom">0.5cm</xsl:attribute>
    </xsl:attribute-set>
    
    <xsl:attribute-set name="italic">
        <xsl:attribute name="font-size">10pt</xsl:attribute>
        <xsl:attribute name="font-style">italic</xsl:attribute>
    </xsl:attribute-set>
    
    <xsl:attribute-set name="lg">
        <xsl:attribute name="font-size">10pt</xsl:attribute>
        <xsl:attribute name="text-align">left</xsl:attribute>
        <xsl:attribute name="margin-left">0.5cm</xsl:attribute>
        <xsl:attribute name="margin-bottom">0.5cm</xsl:attribute>
    </xsl:attribute-set>
    
    <!-- XML-Dokumentwurzel -->
    <xsl:template match="/">
        <fo:root>
            <fo:layout-master-set>
                <fo:simple-page-master master-name="A4" margin="20mm">
                    <fo:region-body margin-top="20mm" margin-bottom="20mm"/>
                    <fo:region-before extent="20mm"/>
                    <fo:region-after extent="20mm"/>
                </fo:simple-page-master>
            </fo:layout-master-set>
            <fo:page-sequence master-reference="A4">
                <fo:static-content flow-name="xsl-region-before">
                    <fo:block border-bottom="0.5pt solid black">IDE Autumn School 2012</fo:block>
                </fo:static-content>
                <fo:static-content flow-name="xsl-region-after">
                    <fo:block xsl:use-attribute-sets="standard" text-align="center">&#x2014; <fo:page-number/> &#x2014;</fo:block>
                </fo:static-content>
                <fo:flow flow-name="xsl-region-body">
                    <fo:block xsl:use-attribute-sets="title">
                        <!-- Titel auslesen -->
                        <xsl:value-of select="//tei:title/tei:quote" />
                    </fo:block>
                    <fo:block xsl:use-attribute-sets="italic" margin-bottom="0.5cm">
                        <!-- Autor (Vorname Nachname) auslesen -->
                        <xsl:value-of select="substring-after(//tei:author, ',')" />
                        <xsl:text> </xsl:text>
                        <xsl:value-of select="substring-before(//tei:author, ',')" />
                    </fo:block>
                    <!-- Tabelle erzeugen -->
                    <fo:table>
                        <fo:table-body>
                            <fo:table-row>
                                <!-- in Zelle 1 Regelwerk für die Verarbeitung der Strophen aufrufen -->
                                <fo:table-cell><xsl:apply-templates select="tei:TEI/tei:text/tei:body/tei:div/tei:lg" /></fo:table-cell>
                                <!-- in Zelle 2 Regelwerk für die Verarbeitung des Bildes aufrufen -->
                                <fo:table-cell text-align="right"><xsl:apply-templates select="//tei:figure" /></fo:table-cell>
                            </fo:table-row>
                        </fo:table-body>
                    </fo:table>
                    
                </fo:flow>
            </fo:page-sequence>
        </fo:root>
    </xsl:template>
    
    <!-- Regelwerk für die Verarbeitung der Strophen -->
    <xsl:template match="//tei:lg">
        <fo:block xsl:use-attribute-sets="lg">
            <xsl:apply-templates />
        </fo:block>
    </xsl:template>
    
    <!-- Regelwerk für die Verarbeitung der Zeilen -->
    <xsl:template match="//tei:l">
        <xsl:apply-templates /><fo:block />
    </xsl:template>
    
    <!-- Regelwerk für die Anzeige des Bildes -->
    <xsl:template match="tei:figure">
        <fo:block>
            <fo:external-graphic content-width="5cm">
                <xsl:attribute name="src">
                    <xsl:value-of select="tei:graphic/@url" />
                </xsl:attribute>
            </fo:external-graphic>
        </fo:block>
    </xsl:template>
    
</xsl:stylesheet>